pecos.simulators.paulifaultprop.gates\_two\_qubit
=================================================

.. automodule:: pecos.simulators.paulifaultprop.gates_two_qubit







   .. rubric:: Functions

   .. autosummary::

      CX
      CY
      CZ
      G2
      II
      SWAP
      SXX
      SXXdg
      SYY
      SYYdg
      SZZ
      SZZdg
